# TkinerFileExplorer

A simple and efficient file explorer written in python tkinker

I have the idea to develop it because the performance of explorer in win11 is extremely bad, some of the third part file exporer had some unexpectable bug, so i want to develop a simple but features are enough to use file explorer in python.

currently not usable, I'm on it to develop.
